function erp = average_epochs(epo)
%AVERAGE_EPOCHS - Classwise calculated averages
%
%Synopsis:
% EPO= average_epochs(EPO)
%
%Arguments:
% EPO -      data structure of epoched data
%
%Returns:
% ERP     - updated data structure with fields
%  .x     - classwise means
%  .N     - vector of epochs per class across which average was calculated


[T,nChannels,nEpochs] = size(epo.x);
nClasses = size(epo.y,1);

erp = epo;  % copy all fields of epo into erp
epo.x = reshape(epo.x,[T*nChannels nEpochs]);   % concatenate first two dimensions
erp.x = zeros(T*nChannels,nClasses);    % pre-allocate erps

for ci = 1:nClasses
    erp.x(:,ci) = mean(epo.x(:,logical(epo.y(ci,:))),2);    % compute class mean
end
erp.x = reshape(erp.x,[T nChannels nClasses]);  % reshape first two dimensions

erp.y = eye(size(epo.y,1));
