
%%
load oddballVPei.mat

ival = [-200 1000];
base_ival = [-200 -100];


%% segment data, apply baseline correction and compute ERPs
epo = make_epochs_(cnt,mrk,ival);
epo = baseline_epochs_(epo,base_ival);
erp = average_epochs_(epo);


%% plot single trial epochs for channel Cz
iCz = find(strcmp(cnt.clab,'Cz'));
clrs = [0 0 1 ; 0 .5 0];
ttl = {'target epochs at Cz','non-target epochs at Cz'};

figure
for ii = 1:2
    subplot(2,1,ii)
    hold on
    iCls = find(epo.y(ii,:));
    plot(epo.t,squeeze(epo.x(:,iCz,iCls)),'color',clrs(ii,:))
    xlabel('ms')
    ylabel('\muV')
    title(ttl{ii})
end

% -> although noisy, the impact of target cue approximately 300 ms after
% cue onset is clearly visible, contrary to non-target

%% plot ERPs for channel Cz
figure
plot(erp.t,squeeze(erp.x(:,iCz,:)),'linewidth',2)
xlabel('ms')
ylabel('\muV')
title('ERPs at channel Cz')
legend('target','non-target')

% -> the average over epochs shows a clearer picture than single trials
% with a negative peak at -250 ms and a positive peak at 340 ms

%% plot scalp topographies of ERPs at t=250ms and t=320ms
tt = [250 320]; % msec
ti =  find(erp.t==tt(1)|erp.t==tt(2));

clim = [min(erp.x(:)) max(erp.x(:))];

cls_ttl = {'target','non-target'};
tm_ttl = {'250 ms','320 ms'};

figure
for ii = 1:2
    for jj = 1:2
        subplot(2,2,jj+2*(ii-1))
        scalpmap(mnt,erp.x(ti(jj),:,ii));
        set(gca,'clim',clim)
        title([cls_ttl{ii} ', ' tm_ttl{jj}])
    end
end

% -> while the low potential is rather homogeneous across channels for
% non-targets, for targets we see that the ERP has its largest impact in
% central channels

