function epo= make_epochs(cnt, mrk, ival)
%MAKEEPOCHS - Segment continuous signals into epochs
%
%Synopsis:
% EPO= make_epochs(CNT, MRK, IVAL)
%
%Arguments:
% CNT    - continuous data
% MRK    - struct for class markers
% IVAL   - time interval relative to marker [start ms, end ms]
%
%Returns:
% EPO -  structure of epoched signals
%         .x     - signals (time x channels x epochs)
%         .y     - class labels
%         .t     - time axis
%         .fs    - sampling interval
%         .clab  - channel labels
%         .className - cell of names of each class


dt = 1000/cnt.fs;   % time resolution of continuous data
nChannels = size(cnt.x,2);  % number of channels
nEpochs = length(mrk.time); % number of epochs

epo.t = ival(1):dt:ival(end);   % time axis
nSamples = length(epo.t);   % number of samples per epoch

pos_zero = ceil((mrk.time)/dt); % index of event times in mrk.time
% indeces of all epochs as a nSamples x nEpochs matrix
epo_ind = (ival(1)/dt:ival(2)/dt)'*ones(1,nEpochs) + ones(nSamples,1)*pos_zero;
% extract expochs and reshape
epo.x = reshape(cnt.x(epo_ind, :), [nSamples nEpochs nChannels]);
% permute dimensions to the required shape
epo.x = permute(epo.x, [1 3 2]);

% update remaining fields
epo.y = mrk.y;
epo.fs = cnt.fs;
epo.clab = cnt.clab;
epo.className = mrk.className;
